@@ -31,7 +31,9 @@ def get_section_regex(tg, beg_section_name, end_section_name):
 def get_section_beg_end(tg, req_section):
         sections_dict = {'̩':['ͶĿ','ͶʷΧ','Ͷʲ','ҵȽϻ׼','Ͷ','ͶʽֹΪ'],
                          '':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷʷʽ','ͶʱͶ','ͶʽֹΪ',''],
-                         '':['ͶĿ','ͶʷΧ','Ͷ','׾Լ¶','ȫݶڴȨͬ','Ԥֹ','˽ļзشʩ','𱸰ǰֽ','ȯ','Ͷʾ'],
+                         '1':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','׾Լ¶','ȫݶڴȨͬ','Ԥֹ','˽ļзشʩ','𱸰ǰֽ','ȯ','Ͷʾ'],
+                         '2':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','׾Լ¶','ȫݶڴȨͬ','Ԥֹ','˽ļзشʩ','𱸰ǰֽ','ڴ͸ԭԼ','ȯ֤ȯҵУ','Ͷʾ'],
+                         '3':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','˽ļ','ȫݶ','Ԥֹ','ȯ','Ͷʾ','Ͷʾ'],
                          '':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','Ͷʾָ','ҵȽϻ׼','տ','ڴ͸ԭԼ','ͶʽֹΪ','ʹƲͶ֤ȯȨԭ򼰷','',''],
                          '':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','Ͷʾָͱ','տ','׼ͻ',''],
                          '1':['ͶĿ','ͶʷΧ','ͶʷΧı','Ͷʲ','Ͷ','ֹΪ','ͻ','ȫݶڴȨͬ⣺','Ԥƽֻ','ʡȯ֤ȯҵ','йͶʼලΧ'],
